#!/bin/sh
#
#------------------------------------------------------------------------------------
# Standalone HIBIKI startup shell script
#
# Environment Variables
#
#       HIBIKI_USER             User's mid, or loginUserID. e.g. 1000015 or ito.
#                               Default is system user(1000000).
#
#       HIBIKI_LOCALE           User's locale, such as ja, or en, etc.
#                               Default is system default locale setting.
#
#       HIBIKI_TIMEZONE         User's timezone, such as JST, or GMT, etc.
#                               Default is system default timezone setting.
#
#       HIBIKI_CHECK_SCHEMA     Whether to check Database schema on startup.
#                               Default is true.
#
#       HIBIKI_WEBAPP_HOME      Deployed directory of hibiki.war under tomcat 4,
#                               tomcat 5, tomcat 6, or tomcat 7.
#                               Default is /opt/jakarta-tomcat/webapp/hibiki
#
#       HIBIKI_CONF             May point at your special hibiki config file,
#                               Such as /etc/hibiki/standalone-hibiki.xml.
#                               Default is /etc/hibiki/hibiki.xml.
#                               Attention: if you set HIBIKI_CONF file pointed
#                               under directory other than /etc/hibiki, you MUST
#                               also set HIBIKI_CONF_DIR to the correct place.
#
#       HIBIKI_CONF_DIR         May point at your special hibiki config directory.
#                               Default is the parent directory of $HIBIKI_CONF.
#
#       HIBIKI_MODULES_HOME     Directory of HIBIKI modules. Must be in the
#                               same as hibiki.modules assigned by $HIBIKI_CONF.
#                               Default is /var/hibiki/modules
#
#       EXTRA_CLASSPATH         May point at your extra classpath, something like
#                               /home/hibiki/lib/my-pkg1.jar:/home/hibiki/classes
#                               This is optional, no default value.
#
#       JVMOPT                  Can be plural. Such as heap size: -Xmx2G
#                               This is also optional, no explicit default value.
#
#       EXEC_USER               Please do not use this Environment Variables.
#                               This is standalone.sh execute user.
#
# e.g. for simple java class
#       hibiki% HIBIKI_CHECK_SCHEMA=false JVMOPT=-Xmx1024M ./standalone.sh mypkg.myclass
#
#------------------------------------------------------------------------------------

STANDALONE_SCRIPT_VERSION="1.0"

##################################################
#
# Guess and Validate environment variables
#
##################################################

#
# guess HIBIKI_WEBAPP_HOME
#
if [ -z "$HIBIKI_WEBAPP_HOME" ]; then
        # guess
        HIBIKI_WEBAPP_HOME=/opt/jakarta-tomcat/webapps/hibiki
fi

#
# check HIBIKI_WEBAPP_HOME
#
if [ ! -d "$HIBIKI_WEBAPP_HOME" ]; then
        echo "env HIBIKI_WEBAPP_HOME not set, abort."
        exit 1
fi

#
# guess servlet.jar/servlet-api.jar
#
WEBAPPS=`dirname $HIBIKI_WEBAPP_HOME`
CATALINA_HOME=`dirname $WEBAPPS`

#
# try Tomcat4
#
if [ -z "$SERVLET_JAR" ]; then
        # guess
        SERVLET_JAR=$CATALINA_HOME/common/lib/servlet.jar
fi

#
# try Tomcat6, Tomcat7
#
if [ ! -f "$SERVLET_JAR" ]; then
        # guess
        SERVLET_JAR=$CATALINA_HOME/lib/servlet-api.jar
        JSP_JAR=$CATALINA_HOME/lib/jsp-api.jar
fi

#
# try Tomcat5
#
if [ ! -f "$SERVLET_JAR" ]; then
        # guess
        SERVLET_JAR=$CATALINA_HOME/common/lib/servlet-api.jar
        JSP_JAR=$CATALINA_HOME/common/lib/jsp-api.jar
fi

#
# check servlet.jar/servlet-api.jar
#
if [ ! -f "$SERVLET_JAR" ]; then
        echo "servlet.jar not found, abort."
        exit 1
fi

#
# concate tomcat jars if necessary
#
if [ -n $JSP_JAR ]; then
        SERVLET_JAR=$SERVLET_JAR:$JSP_JAR
fi

#
# guess /var/hibiki/modules
#
if [ -z "$HIBIKI_MODULES_HOME" ]; then
        if [ -d "/var/hibiki/modules" ]; then
                HIBIKI_MODULES_HOME="/var/hibiki/modules"
        fi
fi

#
# check /var/hibiki/modules
#
if [ ! -d "$HIBIKI_MODULES_HOME" ]; then
        echo "HIBIKI_MODULES_HOME=$HIBIKI_MODULES_HOME is not a directory, abort."
        exit 1;
fi

#
# standalone.sh execute user
#
if [ -z "$EXEC_USER" ]; then
     EXEC_USER="hibiki"
fi

##################################################
#
# Build classpath: same order as SDBTool
#
##################################################

# servlet
cp="$SERVLET_JAR"

# WEB-INF/lib
for jar in "$HIBIKI_WEBAPP_HOME"/WEB-INF/lib/*.jar
do
        cp=${cp}:$jar
done

# WEB-INF/classes
cp="${cp}:$HIBIKI_WEBAPP_HOME/WEB-INF/classes"

# use /var/hibiki/modules
for jar in "$HIBIKI_MODULES_HOME"/*.jar
do
        cp=${cp}:$jar
done

# use EXTRA_CLASSPATH
if [ -n "$EXTRA_CLASSPATH" ]; then
        cp="${cp}:$EXTRA_CLASSPATH"
fi

export CLASSPATH=$cp



##################################################
#
# JVM Options
#
##################################################

JVMOPTIONS="-Dhibiki.webapp.home=$HIBIKI_WEBAPP_HOME"
if [ -n "$HIBIKI_CHECK_SCHEMA" ]; then
        JVMOPTIONS="$JVMOPTIONS -Dhibiki.system.database.check-schema-on-startup=$HIBIKI_CHECK_SCHEMA"
fi
if [ -n "$HIBIKI_CONF_DIR" ]; then
        JVMOPTIONS="$JVMOPTIONS -Dhibiki.confDirectory=$HIBIKI_CONF_DIR"
fi
if [ -n "$HIBIKI_CONF" ]; then
        JVMOPTIONS="$JVMOPTIONS -Dhibiki.conf=$HIBIKI_CONF"
fi
if [ -n "$HIBIKI_USER" ]; then
        JVMOPTIONS="$JVMOPTIONS -Dhibiki.user=$HIBIKI_USER"
fi
if [ -n "$HIBIKI_LOCALE" ]; then
        JVMOPTIONS="$JVMOPTIONS -Dhibiki.locale=$HIBIKI_LOCALE"
fi
if [ -n "$HIBIKI_TIMEZONE" ]; then
        JVMOPTIONS="$JVMOPTIONS -Dhibiki.timezone=$HIBIKI_TIMEZONE"
fi
if [ -n "$JVMOPT" ]; then
        JVMOPTIONS="$JVMOPT $JVMOPTIONS"
fi

#
# if your standalone command becomes very slow after many executions,
# try un-comment following option:
#
#JVMOPTIONS="$JVMOPTIONS -Djava.security.egd=file:/dev/../dev/urandom"


##################################################
#
# Validate commandline arguments
#
##################################################

usage()
{
        cat << EOF
Usage: standalone.sh <commands>
commands:
  --help                        Print this usage
  --version                     Print the version of this script
  --printcmd                    Print java command
  --printenv                    Print Environment variables
  --print-classpath             Print CLASSPATH used by the java command
  --print-classpath-nl          Print CLASSPATH line by line used by the java command
  mypkg.myclass arg1 arg2 ...   Execute java main class with arguments

Ex. for java class
  % HIBIKI_CHECK_SCHEMA=false EXTRA_CLASSPATH=/home/hibiki/jar/mylib.jar ./standalone.sh jp.co.dreamarts.someproj.batch.DailyBackup

EOF
}

if [ $# -eq 0 ]; then
        usage
        exit 1
fi

case "$1" in
        --version)
                echo "Standalone script version: $STANDALONE_SCRIPT_VERSION"
                exit 1
                ;;
        --help)
                usage
                exit 1
                ;;
        --print-classpath)
                echo "$CLASSPATH"
                exit 1
                ;;
        --print-classpath-nl)
                echo $CLASSPATH|tr ':' '\n'
                exit 1
                ;;
        --printcmd)
                shift
                echo "$JAVA_HOME/bin/java $JVMOPTIONS $*"
                exit 1
                ;;
        --printenv)
                echo "HIBIKI_USER=$HIBIKI_USER"
                echo "HIBIKI_LOCALE=$HIBIKI_LOCALE"
                echo "HIBIKI_TIMEZONE=$HIBIKI_TIMEZONE"
                echo "HIBIKI_CHECK_SCHEMA=$HIBIKI_CHECK_SCHEMA"
                echo "HIBIKI_WEBAPP_HOME=$HIBIKI_WEBAPP_HOME"
                echo "HIBIKI_CONF=$HIBIKI_CONF"
                echo "HIBIKI_CONF_DIR=$HIBIKI_CONF_DIR"
                echo "HIBIKI_MODULES_HOME=$HIBIKI_MODULES_HOME"
                echo "EXTRA_CLASSPATH=$EXTRA_CLASSPATH"
                echo "JVMOPT=$JVMOPT"
                exit 1
                ;;
        *)
                ;;
esac

##################################################
#
# Execute the command
#
##################################################
JAVA_PATH="$JAVA_HOME/bin/java"
EXEC_COMMAND="$JAVA_PATH $JVMOPTIONS $*"

USERID=`whoami`
if [ "$USERID" = "root" ]; then
  echo "standalone.sh must be execute by $EXEC_USER user. become $EXEC_USER user."
  exec su $EXEC_USER -c "$EXEC_COMMAND"
elif [ "$USERID" != "$EXEC_USER" ]; then
  echo "standalone.sh must be execute by $EXEC_USER user."
  exit 1
else
  exec $EXEC_COMMAND
fi
exit $?
